set more off
capture log close
qui log using "Table 1, Row 3 (2nd stage 1st diff); 2010-08-06.out", text replace
qui log close


capture program drop regrs_poes
program regrs_poes

capture log close
log using "Table 1, Row 3 (2nd stage 1st diff); `1'; 2010-08-06.out", text replace

display "`1'"

use ano c g q prof `1' using "ports_entry q 2010-08-06", clear

ren ano year
format year %4.0f
ta year, gen(y)
ren year ano
compress
estimates clear

if `2'==1 {
	regr `1' y2-y25
	est sto AA1, title("1")
	}

if `2'==2 {
	areg `1' y2-y25, absorb(prof)
	est sto AA1, title("2")
	}

if `2'==3 {
	areg `1' y2-y25, absorb(g)
	est sto AA1, title("3")
	}

if `2'==1 local abc="OLS"
if `2'==2 local abc="Job fixed effects"
if `2'==3 local abc="Job-Firm fixed effects"

matrix d1=e(b)
matrix d2=d1[1,1..24]

gen sum_ports=.
egen sum_c=sum(c) if `1'~=., by(ano)
foreach z of numlist 1982/1989 1991/2000 2002/2008 {
	qui count if ano==`z' & `1'~=.
	local cnss_d`z' `r(N)'
	replace sum_ports=`cnss_d`z'' if ano==`z'
	qui sum sum_c if ano==`z' & `1'~=.
	local cnss_e`z' `r(mean)'
	display "`cnss_d`z'' `cnss_e`z''"
	}

*drop if `1'~=. // para que esta linha na versao anterior?

sort ano
keep if ano~=ano[_n-1] 
gen coef_f=.
gen cnss_f=.
gen cnss_g=.

ta sum_ports

qui foreach v of numlist 1/24 {
	local z=`v'+1982
	if `v'>7 { 
		local z=`v'+1983
		}
	if `v'>17 { 
		local z=`v'+1984
		}
	replace coef_f=d2[1,`v'] if ano==`z' 
	replace cnss_f=`cnss_d`z'' if ano==`z'
	replace cnss_g=`cnss_e`z'' if ano==`z'
	}
replace coef_f=0 if ano==1982

replace cnss_f=`cnss_d1982' if ano==1982

keep if coef_f~=.

sort ano
merge ano using d_ur_eurostat3 // alterado em rel.  versao anterior
keep if _merge==3
drop _merge

gen time=ano

sort time // nova linha

list time coef_f
gen coef_f2=coef_f
replace coef_f2=coef_f2-coef_f[_n-1]
drop coef_f
gen coef_f=coef_f2
drop coef_f2

gen s=12
replace s=24 if ano==1991 | ano==2002
replace s=19 if ano==1994
gen s2=s^2

gen d_ur_eurostat2=d_ur/100
label var d_ur_eurostat2 "Change Unempl. rate"
label var s "s"
label var s2 "(s^2)"

regr coef_f d_ur_eurostat2 s  [aweight=cnss_f] // the aweight bit is new wrt to the 2009-01-20 file
scalar mss1=e(mss)
predict res, r
est sto A1, title("1")
capture estat dwatson   
capture scalar dw1=r(dw)

regr coef_f d_ur_eurostat2 s s2 [aweight=cnss_f] 
scalar mss2=e(mss)
est sto A2, title("2")
capture estat dwatson   
capture scalar dw2=r(dw)

regr coef_f d_ur_eurostat2  [aweight=cnss_f] 
scalar mss3=e(mss)
est sto A3, title("3")
capture estat dwatson   
capture scalar dw3=r(dw)

gen inv=1/sum_ports
gen res2=res^2
regr res2 inv 		// [aweight=cnss_f] - versao anterior
est sto A4, title("4")

gen res2_weighted=(res*sqrt(sum_ports))^2
regr res2_weighted sum_ports 		// alterado 
est sto A5, title("5")

list time ur d_ur sum_ports sum_c coef_f cnss_f cnss_g


drop res res2 inv res2_weighted



regr coef_f d_ur_eurostat2 s 
scalar mssC1=e(mss)
predict res, r
est sto C1, title("1")
capture estat dwatson   
scalar Cdw1=r(dw)

regr coef_f d_ur_eurostat2 s s2
scalar mssC2=e(mss)
est sto C2, title("2")
capture estat dwatson   
scalar Cdw2=r(dw)

regr coef_f d_ur_eurostat2 
scalar mssC3=e(mss)
est sto C3, title("3")
capture estat dwatson   
scalar Cdw3=r(dw)

gen inv=1/sum_ports
gen res2=res^2
regr res2 inv 		// [aweight=cnss_f] - versao anterior
est sto C4, title("4")

gen res2_weighted=(res*sqrt(sum_ports))^2
regr res2_weighted sum_ports 		// alterado 
est sto C5, title("5")

list time ur d_ur sum_ports sum_c coef_f cnss_f cnss_g


drop res res2 inv res2_weighted


* surpressing the intercept

regr coef_f d_ur_eurostat2 s, noconstant 
scalar mssE1=e(mss)
predict res, r
est sto E1, title("1")
capture estat dwatson   
scalar Edw1=r(dw)

regr coef_f d_ur_eurostat2 s s2, noconstant
scalar mssE2=e(mss)
est sto E2, title("2")
capture estat dwatson   
scalar Edw2=r(dw)

regr coef_f d_ur_eurostat2, noconstant 
scalar mssE3=e(mss)
est sto E3, title("3")
capture estat dwatson   
scalar Edw3=r(dw)

gen inv=1/sum_ports
gen res2=res^2
regr res2 inv 		// [aweight=cnss_f] - versao anterior
est sto E4, title("4")

gen res2_weighted=(res*sqrt(sum_ports))^2
regr res2_weighted sum_ports 		// alterado 
est sto E5, title("5")

list time ur d_ur sum_ports sum_c coef_f cnss_f cnss_g

drop res res2 inv res2_weighted


* teste de robustez - questao da sazonalidade

drop if ano==1994 // passa de marco para outubro


regr coef_f d_ur_eurostat2 s, noconstant 
scalar mssD1=e(mss)
predict res, r
est sto D1, title("1")
capture estat dwatson   
scalar Ddw1=r(dw)

regr coef_f d_ur_eurostat2 s s2, noconstant
scalar mssD2=e(mss)
est sto D2, title("2")
capture estat dwatson   
scalar Ddw2=r(dw)

regr coef_f d_ur_eurostat2, noconstant 
scalar mssD3=e(mss)
est sto D3, title("3")
capture estat dwatson   
scalar Ddw3=r(dw)

gen inv=1/sum_ports
gen res2=res^2
regr res2 inv 		// [aweight=cnss_f] - versao anterior
est sto D4, title("4")

gen res2_weighted=(res*sqrt(sum_ports))^2
regr res2_weighted sum_ports 		// alterado 
est sto D5, title("5")

list time ur d_ur sum_ports sum_c coef_f cnss_f cnss_g


drop res res2 inv res2_weighted





compress
save "Table 1, Row 3 (2nd stage 1st diff); `1'; 2010-08-06", replace
log close

qui log using "Table 1, Row 3 (2nd stage 1st diff); 2010-08-06.out", text append

if "`1'"=="mode_ln_rembaseh" local titulo "Wage (mode log base hourly wage)"
if "`1'"=="ln_rembaseh" local titulo "Wage (log mean base hourly wage)"
if "`1'"=="ln_remh" local titulo "Wage (log mean total hourly wage)"
if "`1'"=="ln_c" local titulo "POE (log) size"
if "`1'"=="ln_educ" local titulo "Schooling (log mean)"

di ""
di "*************************************************************************************"
di "*************************************************************************************"
di "*************************************************************************************"
di ""

estout AA1, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(y2 y3 y4 y5 y6 y7 y8 y9 y10 y11 y12 y13 y14 y15 y16 y17 y18 y19 y20 y21 y22 y23 y24 y25 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 1 - `titulo' Cyclicality - 1st stage (estimation: `abc')") collabels("" "") prehead(@title "Dependent variable: `1'")  ///
	prefoot("") postfoot("" "Notes:")

capture scalar dw1_t=string(dw1)
capture scalar dw2_t=string(dw2)
capture scalar dw3_t=string(dw3)
capture scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mss1)
scalar mss2_t=string(mss2)
scalar mss3_t=string(mss3)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout A1 A2 A3, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(d_ur_eurostat2 s s2 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 2a - `titulo' Cyclicality - 2nd stage (estimation: `abc') - weighted") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text

estout A4, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(inv _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 2b - Heteroskedasticity test 1 - weighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")

estout A5, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(sum_ports _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 2c - Heteroskedasticity test 2 - weighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")


di ""
di "*************************************************************************************"
di ""

capture scalar dw1_t=string(Cdw1)
capture scalar dw2_t=string(Cdw2)
capture scalar dw3_t=string(Cdw3)
capture scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mssC1)
scalar mss2_t=string(mssC2)
scalar mss3_t=string(mssC3)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout C1 C2 C3, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(d_ur_eurostat2 s s2 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 3a - `titulo' Cyclicality - 2nd stage (estimation: `abc') - unweighted") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text

estout C4, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(inv _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 3b - Heteroskedasticity test 1 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")

estout C5, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(sum_ports _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 3c - Heteroskedasticity test 2 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")


di ""
di "*************************************************************************************"
di ""



capture scalar dw1_t=string(Ddw1)
capture scalar dw2_t=string(Ddw2)
capture scalar dw3_t=string(Ddw3)
capture scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mssD1)
scalar mss2_t=string(mssD2)
scalar mss3_t=string(mssD3)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout E1 E2 E3, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(d_ur_eurostat2 s s2 ) legend label  varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 4a - `titulo' Cyclicality - 2nd stage (estimation: `abc') - unweighted - Supressing the intercept") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text

estout E4, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(inv _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 4b - Heteroskedasticity test 1 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")

estout E5, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(sum_ports _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 4c - Heteroskedasticity test 2 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")


di ""
di "*************************************************************************************"
di ""



capture scalar dw1_t=string(Ddw1)
capture scalar dw2_t=string(Ddw2)
capture scalar dw3_t=string(Ddw3)
capture scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mssD1)
scalar mss2_t=string(mssD2)
scalar mss3_t=string(mssD3)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout D1 D2 D3, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(d_ur_eurostat2 s s2 ) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 5a - `titulo' Cyclicality - 2nd stage (estimation: `abc') - unweighted - Removing 1994") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text

estout D4, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(inv _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 5b - Heteroskedasticity test 1 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")

estout D5, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(sum_ports _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 53c - Heteroskedasticity test 2 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")


di ""
di "*************************************************************************************"
di ""


qui log close

end


regrs_poes mode_ln_rembaseh 3

regrs_poes ln_rembaseh 3

regrs_poes ln_remh 3


