set more off
capture log close
qui log using "Table 1, Rows 1, 2, 4, 5, and 6; 2010-08-06.out", text replace
qui log close


capture program drop regrs_poes
program regrs_poes

use ano c g q prof `1' current_U using "ports_entry q 2010-08-06", clear

ren ano year
format year %4.0f
ta year, gen(y)
ren year ano
compress
estimates clear

if `2'==1 {
	regr `1' y2-y25
	est sto AA1, title("1")
	}

if `2'==2 {
	areg `1' y2-y25, absorb(prof)
	est sto AA1, title("2")
	}

if `2'==3 {
	areg `1' y2-y25, absorb(g)
	est sto AA1, title("3")
	}

if `2'==1 local abc="OLS"
if `2'==2 local abc="Job fixed effects"
if `2'==3 local abc="Job-Firm fixed effects"

matrix d1=e(b)
matrix d2=d1[1,1..24]

gen sum_ports=.
egen sum_c=sum(c) if `1'~=., by(ano)
foreach z of numlist 1982/1989 1991/2000 2002/2008 {
	qui count if ano==`z' & `1'~=.
	local cnss_d`z' `r(N)'
	replace sum_ports=`cnss_d`z'' if ano==`z'
	qui sum sum_c if ano==`z' & `1'~=.
	local cnss_e`z' `r(mean)'
	display "`cnss_d`z'' `cnss_e`z''"
	}

sort ano
keep if ano~=ano[_n-1] 
gen coef_f=.
gen cnss_f=.
gen cnss_g=.

ta sum_ports

qui foreach v of numlist 1/24 {
	local z=`v'+1982
	if `v'>7 { 
		local z=`v'+1983
		}
	if `v'>17 { 
		local z=`v'+1984
		}
	replace coef_f=d2[1,`v'] if ano==`z' 
	replace cnss_f=`cnss_d`z'' if ano==`z'
	replace cnss_g=`cnss_e`z'' if ano==`z'
	}
replace coef_f=0 if ano==1982

replace cnss_f=`cnss_d1982' if ano==1982

keep if coef_f~=.
ren ano time

gen time_b=time 
replace time=(time-1981)*12
replace time=time+2 if time_b<=1993 
replace time=time+9 if time_b>1993

tsset time_b
gen time2=(time^2)/100

replace current_U=current_U/100
label var current_U "Unempl. rate"
label var time "Trend"
label var time2 "(Trend^2)/100"

regr coef_f current_U time  [aweight=cnss_f]
scalar mss1=e(mss)
predict res, r
est sto A1, title("1")
estat dwatson  
scalar dw1=r(dw)

regr coef_f current_U time time2 [aweight=cnss_f] 
scalar mss2=e(mss)
est sto A2, title("2")
estat dwatson  
scalar dw2=r(dw)

regr coef_f current_U  [aweight=cnss_f] 
scalar mss3=e(mss)
est sto A3, title("3")
estat dwatson  
scalar dw3=r(dw)

gen inv=1/sum_ports
gen res2=res^2
regr res2 inv 		
est sto A4, title("4")

gen res2_weighted=(res*sqrt(sum_ports))^2
regr res2_weighted sum_ports 		
est sto A5, title("5")

list time current_U sum_ports sum_c coef_f cnss_f cnss_g


drop res res2 inv res2_weighted

regr coef_f current_U time 
scalar mssC1=e(mss)
predict res, r
est sto C1, title("1")
estat dwatson  
scalar Cdw1=r(dw)

regr coef_f current_U time time2
scalar mssC2=e(mss)
est sto C2, title("2")
estat dwatson  
scalar Cdw2=r(dw)

regr coef_f current_U 
scalar mssC3=e(mss)
est sto C3, title("3")
estat dwatson  
scalar Cdw3=r(dw)

gen inv=1/sum_ports
gen res2=res^2
regr res2 inv 		// 
est sto C4, title("4")

gen res2_weighted=(res*sqrt(sum_ports))^2
regr res2_weighted sum_ports 		// 
est sto C5, title("5")


regr coef_f current_U L.current_U time  [aweight=cnss_f] 
scalar mssB1=e(mss)
est sto B1, title("1")
estat dwatson  
scalar Bdw1=r(dw)

regr coef_f current_U L.current_U time time2 [aweight=cnss_f] 
scalar mssB2=e(mss)
est sto B2, title("2")
estat dwatson  
scalar Bdw2=r(dw)

regr coef_f current_U L.current_U  [aweight=cnss_f] 
scalar mssB3=e(mss)
est sto B3, title("3")
estat dwatson  
scalar Bdw3=r(dw)

regr coef_f current_U F.current_U time  [aweight=cnss_f] 
scalar mssB4=e(mss)
est sto B4, title("4")
estat dwatson  
scalar Bdw4=r(dw)

regr coef_f current_U F.current_U time time2 [aweight=cnss_f] 
scalar mssB5=e(mss)
est sto B5, title("5")
estat dwatson  
scalar Bdw5=r(dw)

regr coef_f current_U F.current_U  [aweight=cnss_f] 
scalar mssB6=e(mss)
est sto B6, title("6")
estat dwatson  
scalar Bdw6=r(dw)

regr coef_f current_U L.current_U F.current_U time  [aweight=cnss_f] 
scalar mssB7=e(mss)
est sto B7, title("7")
estat dwatson  
scalar Bdw7=r(dw)

regr coef_f current_U L.current_U F.current_U time time2 [aweight=cnss_f] 
scalar mssB8=e(mss)
est sto B8, title("8")
estat dwatson  
scalar Bdw8=r(dw)

regr coef_f current_U L.current_U F.current_U  [aweight=cnss_f] 
scalar mssB9=e(mss)
est sto B9, title("9")
estat dwatson  
scalar Bdw9=r(dw)


compress
save "Table 1, Rows 1, 2, 4, 5, and 6; `1'; 2010-08-06", replace
log close

qui log using "Table 1, Rows 1, 2, 4, 5, and 6; 2010-08-06.out", text append

if "`1'"=="mode_ln_rembaseh" local titulo "Wage (mode log base hourly wage)"
if "`1'"=="ln_rembaseh" local titulo "Wage (log mean base hourly wage)"
if "`1'"=="ln_remh" local titulo "Wage (log mean total hourly wage)"
if "`1'"=="ln_c" local titulo "POE (log) size"
if "`1'"=="ln_educ" local titulo "Schooling (log mean)"

di ""
di "*************************************************************************************"
di "*************************************************************************************"
di "*************************************************************************************"
di ""

estout AA1, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(y2 y3 y4 y5 y6 y7 y8 y9 y10 y11 y12 y13 y14 y15 y16 y17 y18 y19 y20 y21 y22 y23 y24 y25 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 1 - `titulo' Cyclicality - 1st stage (estimation: `abc')") collabels("" "") prehead(@title "Dependent variable: `1'")  ///
	prefoot("") postfoot("" "Notes:")

scalar dw1_t=string(dw1)
scalar dw2_t=string(dw2)
scalar dw3_t=string(dw3)
scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mss1)
scalar mss2_t=string(mss2)
scalar mss3_t=string(mss3)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout A1 A2 A3, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(current_U time time2 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 2a - `titulo' Cyclicality - 2nd stage (estimation: `abc') - weighted") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text

estout A4, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(inv _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 2b - Heteroskedasticity test 1 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")

estout A5, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(sum_ports _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 2c - Heteroskedasticity test 2 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared weighted residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")


di ""
di "*************************************************************************************"
di ""

scalar dw1_t=string(Cdw1)
scalar dw2_t=string(Cdw2)
scalar dw3_t=string(Cdw3)
scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mssC1)
scalar mss2_t=string(mssC2)
scalar mss3_t=string(mssC3)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout C1 C2 C3, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(current_U time time2 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 3a - `titulo' Cyclicality - 2nd stage (estimation: `abc') - unweighted") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text

estout C4, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(inv _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 3b - Heteroskedasticity test 1 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")

estout C5, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(sum_ports _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 3c - Heteroskedasticity test 2 - unweighted") collabels("" "") prehead(@title "Dependent variable: Squared weighted residuals from 2nd stage regression" "")  ///
	prefoot("") postfoot("" "Notes:")


di ""
di "*************************************************************************************"
di ""

scalar dw1_t=string(Bdw1)
scalar dw2_t=string(Bdw2)
scalar dw3_t=string(Bdw3)
scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mssB1)
scalar mss2_t=string(mssB2)
scalar mss3_t=string(mssB3)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout B1 B2 B3, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(current_U L.current_U time time2 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 4a - `titulo' Cyclicality - 2nd stage (estimation: `abc') - weighted") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text


di ""
di "*************************************************************************************"
di ""

scalar dw1_t=string(Bdw4)
scalar dw2_t=string(Bdw5)
scalar dw3_t=string(Bdw6)
scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mssB4)
scalar mss2_t=string(mssB5)
scalar mss3_t=string(mssB6)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout B4 B5 B6, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(current_U F.current_U time time2 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 4b - `titulo' Cyclicality - 2nd stage (estimation: `abc') - weighted") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text


di ""
di "*************************************************************************************"
di ""

scalar dw1_t=string(Bdw7)
scalar dw2_t=string(Bdw8)
scalar dw3_t=string(Bdw9)
scalar dw_text = "Durbin-Watson statistics are "+ dw1_t+ ", "+dw2_t +" and "+ dw3_t +", respectively."
scalar mss1_t=string(mssB7)
scalar mss2_t=string(mssB8)
scalar mss3_t=string(mssB9)
scalar mss_text = "Model sum of squares statistics are "+ mss1_t+ ", "+mss2_t +" and "+ mss3_t +", respectively."

estout B7 B8 B9, cells(b(star fmt(%9.6f)) se(par([ ])) ) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(%9.3f %9.0g) ///
	labels("R-squared" "No. observations")) keep(current_U L.current_U F.current_U time time2 _cons) legend label varlabels(_cons Constant) varwidth(18) ///
	modelwidth(11) delimiter("") title("Table 4c - `titulo' Cyclicality - 2nd stage (estimation: `abc') - weighted") collabels("" "") prehead(@title "Dependent variable: `1'" "")  ///
	prefoot("") postfoot("" "Notes:")
di dw_text
di mss_text

	
qui log close

end


regrs_poes mode_ln_rembaseh 3

regrs_poes ln_rembaseh 3

regrs_poes ln_remh 3

regrs_poes ln_c 3

regrs_poes educ 3

regrs_poes age 3

regrs_poes exp 3

regrs_poes ten 3

regrs_poes fem 3


