(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29723,        756]*)
(*NotebookOutlinePosition[     30459,        781]*)
(*  CellTagsIndexPosition[     30415,        777]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Alternative cycle variables, Table 2 rows 1 - 4, Table 3", "Title"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(<< 
      Statistics`LinearRegression`\[IndentingNewLine]
    << Graphics`MultipleListPlot`\[IndentingNewLine] (*s\ is\ the\ gap\ in\ \
months\ between\ observations, \ 
      starting\ from\ 1982\ to\ 1983*) \[IndentingNewLine]
    \(s = {12, 12, 12, 12, 12, 12, 12, 24, 12, 12, 19, 12, 12, 12, 12, 12, 
          12, 24, 12, 12, 12, 12, 12, 12};\)\[IndentingNewLine]
    \(year = {1983, 1984, 1985, 1986, 1987, 1988, 1989, 1991, 1992, 1993, 
          1994, 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2005, 
          2006, 2007, 
          2008};\)\[IndentingNewLine] (*wage\ is\ the\ main\ log\ wage\ \
\(series\ --\)\ year\ \(effects\ --\)\ from\ first\ stage\ regression\ set\ \
to\ 0\ in\ 1982; \ 
      there\ are\ 25\ observations\ because\ of\ two\ missing\ years; \ 
      wage, \ unem, \ gdp, \ empl\ etc . \ go\ from\ 82\ to\ 2008; \ 
      t\ always\ refers\ to\ observation\ number, \ not\ time, \ 
      and\ so\ in\ first - 
        difference\ regressions\ observation\ t\ will\ be\ the\ change\ \
between\ observations\ at\ t\ and\ t + 1*) \[IndentingNewLine]
    wage = {0, \(-0.018635\), \(-0.133660\), \(-0.153407\), \(-0.066043\), \
\(-0.018161\), \(-0.051703\), \(-0.048747\), 0.018975, 0.029391, 0.040479, 
        0.063084, 0.044557, 0.083444, 0.078864, 0.116814, 0.143318, 0.136829, 
        0.100203, 0.097675, 0.112108, 0.100245, 0.090582, 0.099470, 
        0.106349}; 
    unem = {7.32, 7.67, 8.85, 9.05, 9.31, 7.71, 6.14, 5.35, 4.2, 3.91, 5.06, 
        7.01, 7.15, 7.15, 6.68, 4.78, 4.26, 3.87, 5.67, 6.48, 7.04, 7.99, 8, 
        7.84, 7.84}; 
    gdp = {16318.4, 16600.1, 16185.6, 16628.4, 16918.6, 18227.9, 19309.8, 
        20628.0, 23142.4, 24349.2, 24012.4, 24814.9, 25428.6, 26176.0, 
        27382.2, 28873.6, 29719.3, 30908.6, 31050.1, 31208.7, 31563.9, 
        32053.6, 32503.8, 33063.0, 32390.0};\[IndentingNewLine]
    \(empl = {4171.7, 4079.8, 4117.1, 4137.5, 4075.1, 4161.7, 4266.4, 4412.4, 
          4540.6, 4582.7, 4541.9, 4520.4, 4552.4, 4627.1, 4774.1, 4888.7, 
          4952.1, 5070.4, 5112.6, 5120.7, 5125.5, 5110.6, 5115.6, 5147.5, 
          5136.9};\)\[IndentingNewLine]
    \(noentryjobs = {137, 160, 137, 181, 210, 219, 231, 244, 238, 265, 269, 
          299, 345, 353, 378, 455, 469, 513, 577, 710, 790, 803, 810, 744, 
          676};\)\)\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Table 2 alternative cycle variables", "Section"],

Cell[BoxData[
    \(date[t_] := 12 + Sum[s[\([j]\)], {j, 1, t - 1}]; 
    data1 = Table[{N[1981 + date[t]/12], date[t], unem[\([t]\)], 
          empl[\([t]\)], gdp[\([t]\)], wage[\([t]\)]}, {t, 1, 
          25}];\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 2  row 1", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Module", "[", 
      RowBox[{\({time, year}\), ",", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"regress", "=", 
              RowBox[{"Regress", "[", 
                RowBox[{
                "data1", ",", \({timex, unemp}\), 
                  ",", \({year, timex, unemp, employ, gdpp}\), 
                  ",", \(IncludeConstant \[Rule] True\), ",", " ", 
                  RowBox[{
                    StyleBox["Weights",
                      "MR"], " ", 
                    StyleBox["->",
                      "MR"], "noentryjobs"}], 
                  ",", \(RegressionReport \[Rule] {ParameterTable, RSquared, 
                      AdjustedRSquared}\)}], "]"}]}], ";", 
            "\[IndentingNewLine]", \(Chop[regress, 10^\((\(-6\))\)]\)}], 
          ")"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", "0.051393075504049104`", "0.027748239071380982`", 
                  "1.8521202506524086`", "0.07747533186821909`"},
                {"timex", "0.0006309761681207848`", "0.00006367710410795908`",
                   "9.908995972100406`", "0"},
                {"unemp", \(-0.01805384136992541`\), 
                  "0.0038294557790062604`", \(-4.714466600946196`\), 
                  "0.0001054160236319152`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{1, timex, unemp}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.8312567411911463`\), 
        ",", \(AdjustedRSquared \[Rule] 0.8159164449357961`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 2  row 2", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Module", "[", 
      RowBox[{\({time, year}\), ",", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"regress", "=", 
              RowBox[{"Regress", "[", 
                RowBox[{
                "data1", ",", \({timex, unemp}\), 
                  ",", \({year, timex, unemp, employ, gdpx}\), 
                  ",", \(IncludeConstant \[Rule] True\), ",", " ", 
                  RowBox[{
                    StyleBox["Weights",
                      "MR"], " ", "\[Rule]", "Automatic"}], 
                  ",", \(RegressionReport \[Rule] {ParameterTable, RSquared, 
                      AdjustedRSquared}\)}], "]"}]}], ";", 
            "\[IndentingNewLine]", \(Chop[regress, 10^\((\(-6\))\)]\)}], 
          ")"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", "0.03841058903267393`", "0.03639614503615573`", 
                  "1.05534772967074`", "0.3027187666805675`"},
                {"timex", "0.0006457407516289106`", "0.0000763855938067342`", 
                  "8.45369813138746`", "0"},
                {"unemp", \(-0.016568740379356454`\), 
                  "0.004713925251667168`", \(-3.5148500442378907`\), 
                  "0.0019532330965217354`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{1, timex, unemp}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.8101875759514628`\), 
        ",", \(AdjustedRSquared \[Rule] 0.7929319010379595`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 2  row 1; log gdp replacing unemployment", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Module", "[", 
      RowBox[{\({year}\), ",", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"regress", "=", 
              RowBox[{"Regress", "[", 
                RowBox[{
                "data1", ",", \({timex, Log[gdpx]}\), 
                  ",", \({year, timex, unemp, employ, gdpx}\), 
                  ",", \(IncludeConstant \[Rule] True\), ",", 
                  RowBox[{
                    StyleBox["Weights",
                      "MR"], " ", 
                    StyleBox["->",
                      "MR"], "noentryjobs"}], 
                  ",", \(RegressionReport \[Rule] {ParameterTable, RSquared, 
                      AdjustedRSquared}\)}], "]"}]}], ";", 
            "\[IndentingNewLine]", \(Chop[regress, 10^\((\(-6\))\)]\)}], 
          ")"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", \(-5.368466774799162`\), 
                  "0.8569975837916656`", \(-6.264272941175789`\), 
                  "2.642214408408882`*^-6"},
                {"timex", \(-0.000663911451084525`\), 
                  "0.00020838625230990338`", \(-3.1859656945947825`\), 
                  "0.004270909784205094`"},
                {\(Log[gdpx]\), "0.5464313091430729`", "0.08817912632745636`",
                   "6.196832877589199`", "3.086573751698296`*^-6"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ BoxForm`e$, TableHeadings -> {{1, timex, 
                Log[ gdpx]}, {"Estimate", "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.8764440202629222`\), 
        ",", \(AdjustedRSquared \[Rule] 0.8652116584686425`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 2  row 1 log employment replacing unemployment", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Module", "[", 
      RowBox[{\({year}\), ",", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"regress", "=", 
              RowBox[{"Regress", "[", 
                RowBox[{
                "data1", ",", \({timex, Log[employ]}\), 
                  ",", \({year, timex, unemp, employ, gdpx}\), 
                  ",", \(IncludeConstant \[Rule] True\), ",", 
                  RowBox[{
                    StyleBox["Weights",
                      "MR"], " ", 
                    StyleBox["->",
                      "MR"], "noentryjobs"}], 
                  ",", \(RegressionReport \[Rule] {ParameterTable, RSquared, 
                      AdjustedRSquared}\)}], "]"}]}], ";", 
            "\[IndentingNewLine]", \(Chop[regress, 10^\((\(-6\))\)]\)}], 
          ")"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", \(-9.436854454868852`\), 
                  "2.6889932078671963`", \(-3.5094378175665955`\), 
                  "0.0019787746667340295`"},
                {"timex", \(-0.00033310467086783934`\), 
                  "0.0002724049309268853`", \(-1.222829079247637`\), 
                  "0.23433267747544673`"},
                {\(Log[employ]\), "1.1293932228669612`", 
                  "0.32381330862379437`", "3.4877912451062594`", 
                  "0.0020842423199511906`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ BoxForm`e$, TableHeadings -> {{1, timex, 
                Log[ employ]}, {"Estimate", "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.7815618168295067`\), 
        ",", \(AdjustedRSquared \[Rule] 0.7617038001776436`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Table 2  row 1 log gdp - log employment replacing unemployment\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Module", "[", 
      RowBox[{\({year}\), ",", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"regress", "=", 
              RowBox[{"Regress", "[", 
                RowBox[{
                "data1", ",", \({time, Log[gdpx/employ]}\), 
                  ",", \({year, time, unemp, employ, gdpx}\), 
                  ",", \(IncludeConstant \[Rule] True\), ",", 
                  RowBox[{
                    StyleBox["Weights",
                      "MR"], " ", 
                    StyleBox["->",
                      "MR"], 
                    StyleBox["noentryjobs",
                      "MR"]}], 
                  StyleBox[",",
                    
                    "MR"], \(RegressionReport \[Rule] {ParameterTable, 
                      RSquared, AdjustedRSquared}\)}], "]"}]}], ";", 
            "\[IndentingNewLine]", \(Chop[regress, 10^\((\(-6\))\)]\)}], 
          ")"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", \(-1.0374782514430163`\), 
                  "0.17547431074546718`", \(-5.912422434004724`\), 
                  "5.979711359010225`*^-6"},
                {"time", \(-0.0004353523123690331`\), 
                  "0.00019085940966037196`", \(-2.2810104733307526`\), 
                  "0.03258908301386638`"},
                {\(Log[gdpx\/employ]\), "0.6925429852935642`", 
                  "0.12373905173180347`", "5.5968021057297825`", 
                  "0.000012584791471592638`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ BoxForm`e$, TableHeadings -> {{1, time, 
                Log[ 
                  Times[ 
                    Power[ employ, -1], gdpx]]}, {"Estimate", "SE", "TStat", 
                "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.8600471607421479`\), 
        ",", \(AdjustedRSquared \[Rule] 0.8473241753550704`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 2  row 3 ", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = 
      Table[{year[\([t]\)], unem[\([t + 1]\)] - unem[\([t]\)], 
          Log[gdp[\([t + 1]\)]] - Log[gdp[\([t]\)]], 
          Log[empl[\([t + 1]\)]] - Log[empl[\([t]\)]], s[\([t]\)], 
          wage[\([t + 1]\)] - wage[\([t]\)]}, {t, 24}]; 
    Module[{year, s}, 
      regress = 
        Regress[data, {unemchange, s}, {year, unemchange, gdpchange, 
            emplchange, s}, IncludeConstant \[Rule] False, 
          RegressionReport \[Rule] {ParameterTable, RSquared, 
              AdjustedRSquared}]; \[IndentingNewLine]Chop[regress, 
        10^\((\(-6\))\)]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"unemchange", \(-0.014812408746046097`\), 
                  "0.0077634648565821085`", \(-1.9079636502105979`\), 
                  "0.06953226166181674`"},
                {"s$328", "0.0004888099180467306`", "0.0005553236785275808`", 
                  "0.8802252397066719`", "0.38825184984075145`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{unemchange, s$328}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.1589831477080974`\), 
        ",", \(AdjustedRSquared \[Rule] 0.08252707022701544`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 2  row 4", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data1 = 
      Table[{year[\([t]\)], unem[\([t + 1]\)] - unem[\([t]\)], 
          Log[gdp[\([t + 1]\)]] - Log[gdp[\([t]\)]], 
          Log[empl[\([t + 1]\)]] - Log[empl[\([t]\)]], s[\([t]\)], 
          wage[\([t + 1]\)] - wage[\([t]\)]}, {t, 10}]; 
    data2 = Table[{year[\([t]\)], unem[\([t + 1]\)] - unem[\([t]\)], 
          Log[gdp[\([t + 1]\)]] - Log[gdp[\([t]\)]], 
          Log[empl[\([t + 1]\)]] - Log[empl[\([t]\)]], s[\([t]\)], 
          wage[\([t + 1]\)] - wage[\([t]\)]}, {t, 12, 24}]; 
    data3 = Join[data1, data2]; 
    Module[{year, 
        s}, \((regress = 
          Regress[data3, {unemchange, s}, {year, unemchange, gdpchange, 
              emplchange, s}, IncludeConstant \[Rule] False, 
            RegressionReport \[Rule] {ParameterTable, RSquared, 
                AdjustedRSquared}]; \[IndentingNewLine]Chop[regress, 
          10^\((\(-6\))\)])\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"unemchange", \(-0.019149102076361176`\), 
                  "0.008330315673188064`", \(-2.29872466153887`\), 
                  "0.03188732047151345`"},
                {"s$342", "0.00028707959879436265`", "0.000567950860955478`", 
                  "0.5054655579030225`", "0.6184961456895737`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{unemchange, s$342}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.21118178753830177`\), 
        ",", \(AdjustedRSquared \[Rule] 0.13605624349433043`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Table 3  row 1 ", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wagex = {0.234199, 0.191219, 0.196711, 0.456424, 0.216912, 0.184465, 
        0.310683, 0.191543, 0.192628, 0.221666, 0.232139, 0.221602, 0.191172, 
        0.379483, 0.178925, 0.220228, 0.189725, 0.179402, 0.185798, 
        0.193338}; 
    sx = {12, 12, 12, 24, 12, 12, 19, 12, 12, 12, 12, 12, 12, 24, 12, 12, 12, 
        12, 12, 12}; 
    yearx = {1987, 1988, 1989, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 
        1998, 1999, 2000, 2002, 2003, 2004, 2005, 2006, 2007, 2008}; 
    datax = Table[{yearx[\([t]\)], unem[\([t + 5]\)] - unem[\([t + 4]\)], 
          sx[\([t]\)], wagex[\([t]\)]}, {t, 20}]; 
    Module[{s, 
        yearx}, \((regress = 
          Regress[datax, {unemchange, s}, {yearx, unemchange, s}, 
            IncludeConstant \[Rule] False, 
            RegressionReport \[Rule] {ParameterTable, RSquared, 
                AdjustedRSquared}]; \[IndentingNewLine]Chop[regress, 
          10^\((\(-6\))\)])\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"unemchange", \(-0.012470861816814657`\), 
                  "0.0038007492497912684`", \(-3.281158791914394`\), 
                  "0.00415031705381758`"},
                {"s$356", "0.016933179243504688`", "0.00028061326993228305`", 
                  "60.34347287849561`", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{unemchange, s$356}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.9950894280492929`\), 
        ",", \(AdjustedRSquared \[Rule] 0.9945438089436588`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 3  row 2", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wagex = {0.249609, 0.220555, 0.213929, 0.501480, 0.240856, 0.199439, 
        0.328169, 0.207624, 0.212330, 0.243168, 0.245048, 0.232202, 0.204998, 
        0.409518, 0.195734, 0.226038, 0.206044, 0.197953, 0.207563, 
        0.211836}; 
    sx = {12, 12, 12, 24, 12, 12, 19, 12, 12, 12, 12, 12, 12, 24, 12, 12, 12, 
        12, 12, 12}; 
    yearx = {1987, 1988, 1989, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 
        1998, 1999, 2000, 2002, 2003, 2004, 2005, 2006, 2007, 2008}; 
    datax = Table[{yearx[\([t]\)], unem[\([t + 5]\)] - unem[\([t + 4]\)], 
          sx[\([t]\)], wagex[\([t]\)]}, {t, 20}]; 
    Module[{s, 
        yearx}, \((regress = 
          Regress[datax, {unemchange, s}, {yearx, unemchange, s}, 
            IncludeConstant \[Rule] False, 
            RegressionReport \[Rule] {ParameterTable, RSquared, 
                AdjustedRSquared}]; \[IndentingNewLine]Chop[regress, 
          10^\((\(-6\))\)])\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"unemchange", \(-0.01512707239535177`\), 
                  "0.003666535070011665`", \(-4.125713270568456`\), 
                  "0.0006348502383638652`"},
                {"s$368", "0.018363016699274502`", "0.000270704097454961`", 
                  "67.83427687986764`", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{unemchange, s$368}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.996112312037636`\), 
        ",", \(AdjustedRSquared \[Rule] 0.9956803467084844`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Table 3  row 3 ", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wagex = {0.264710, 0.223925, 0.232620, 0.452097, 0.242959, 0.203847, 
        0.303090, 0.208361, 0.211600, 0.236223, 0.262469, 0.234057, 0.215916, 
        0.360597, 0.175938, 0.224256, 0.203399, 0.193084, 0.204593, 
        0.217220}; 
    sx = {12, 12, 12, 24, 12, 12, 19, 12, 12, 12, 12, 12, 12, 24, 12, 12, 12, 
        12, 12, 12}; 
    yearx = {1987, 1988, 1989, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 
        1998, 1999, 2000, 2002, 2003, 2004, 2005, 2006, 2007, 2008}; 
    datax = Table[{yearx[\([t]\)], unem[\([t + 5]\)] - unem[\([t + 4]\)], 
          sx[\([t]\)], wagex[\([t]\)]}, {t, 20}]; 
    Module[{s, 
        yearx}, \((regress = 
          Regress[datax, {unemchange, s}, {yearx, unemchange, s}, 
            IncludeConstant \[Rule] False, 
            RegressionReport \[Rule] {ParameterTable, RSquared, 
                AdjustedRSquared}]; \[IndentingNewLine]Chop[regress, 
          10^\((\(-6\))\)])\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"unemchange", \(-0.023082547096445315`\), 
                  "0.0033351840116066663`", \(-6.920921609157542`\), 
                  "1.8081845092882537`*^-6"},
                {"s$759", "0.017776681268477017`", "0.0002462401042042471`", 
                  "72.1924697275628`", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{unemchange, s$759}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.9965815366942399`\), 
        ",", \(AdjustedRSquared \[Rule] 0.9962017074380443`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 3  row 4", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wagex = {0.232943, 0.189263, 0.194088, 0.458921, 0.214596, 0.182649, 
        0.311098, 0.189952, 0.190988, 0.220013, 0.228987, 0.219617, 0.187691, 
        0.380479, 0.177691, 0.218386, 0.186982, 0.176371, 0.181942, 
        0.191543}; 
    sx = {12, 12, 12, 24, 12, 12, 19, 12, 12, 12, 12, 12, 12, 24, 12, 12, 12, 
        12, 12, 12}; 
    yearx = {1987, 1988, 1989, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 
        1998, 1999, 2000, 2002, 2003, 2004, 2005, 2006, 2007, 2008}; 
    datax = Table[{yearx[\([t]\)], unem[\([t + 5]\)] - unem[\([t + 4]\)], 
          sx[\([t]\)], wagex[\([t]\)]}, {t, 20}]; 
    Module[{s, 
        yearx}, \((regress = 
          Regress[datax, {unemchange, s}, {yearx, unemchange, s}, 
            IncludeConstant \[Rule] False, 
            RegressionReport \[Rule] {ParameterTable, RSquared, 
                AdjustedRSquared}]; \[IndentingNewLine]Chop[regress, 
          10^\((\(-6\))\)])\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"unemchange", \(-0.011975259570421594`\), 
                  "0.00404346575890343`", \(-2.961632491644799`\), 
                  "0.008353278190469833`"},
                {"s$771", "0.016840825988125047`", "0.0002985332822278201`", 
                  "56.41188768786351`", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{unemchange, s$771}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.9943842310508686`\), 
        ",", \(AdjustedRSquared \[Rule] 0.9937602567231874`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Table 3  row 5", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wagex = {0.105606, 0.061305, 0.065326, 0.190706, 0.088066, 0.058145, 
        0.110549, 0.065369, 0.066839, 0.096659, 0.104246, 0.096705, 0.064942, 
        0.120981, 0.054811, 0.095760, 0.064279, 0.053926, 0.058674, 
        0.068740}; 
    sx = {12, 12, 12, 24, 12, 12, 19, 12, 12, 12, 12, 12, 12, 24, 12, 12, 12, 
        12, 12, 12}; 
    yearx = {1987, 1988, 1989, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 
        1998, 1999, 2000, 2002, 2003, 2004, 2005, 2006, 2007, 2008}; 
    datax = Table[{yearx[\([t]\)], unem[\([t + 5]\)] - unem[\([t + 4]\)], 
          sx[\([t]\)], wagex[\([t]\)]}, {t, 20}]; 
    Module[{s, 
        yearx}, \((regress = 
          Regress[datax, {unemchange, s}, {yearx, unemchange, s}, 
            IncludeConstant \[Rule] False, 
            RegressionReport \[Rule] {ParameterTable, RSquared, 
                AdjustedRSquared}]; \[IndentingNewLine]Chop[regress, 
          10^\((\(-6\))\)])\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"unemchange", \(-0.011351863321825511`\), 
                  "0.003663659944326235`", \(-3.098503544087298`\), 
                  "0.006199578425393049`"},
                {"s$380", "0.006275421761993476`", "0.00027049182393544405`", 
                  "23.20004231806717`", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{unemchange, s$380}, {"Estimate", 
                "SE", "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.968088631951639`\), 
        ",", \(AdjustedRSquared \[Rule] 0.96454292439071`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 717}},
AutoGeneratedPackage->None,
WindowSize->{1223, 708},
WindowMargins->{{Automatic, 19}, {Automatic, -4}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 73, 0, 95, "Title"],
Cell[1852, 55, 2403, 39, 350, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4280, 98, 54, 0, 73, "Section"],
Cell[4337, 100, 227, 4, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4601, 109, 33, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[4659, 113, 836, 19, 90, "Input"],
Cell[5498, 134, 1148, 25, 73, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6695, 165, 33, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[6753, 169, 780, 17, 90, "Input"],
Cell[7536, 188, 1142, 25, 73, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8727, 219, 65, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[8817, 223, 829, 19, 90, "Input"],
Cell[9649, 244, 1182, 25, 79, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10880, 275, 71, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[10976, 279, 831, 19, 90, "Input"],
Cell[11810, 300, 1206, 26, 73, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13065, 332, 89, 2, 73, "Section"],

Cell[CellGroupData[{
Cell[13179, 338, 950, 23, 90, "Input"],
Cell[14132, 363, 1297, 29, 89, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15478, 398, 34, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[15537, 402, 610, 12, 110, "Input"],
Cell[16150, 416, 1036, 23, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17235, 445, 33, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[17293, 449, 916, 17, 150, "Input"],
Cell[18212, 468, 1033, 23, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19294, 497, 35, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[19354, 501, 964, 17, 150, "Input"],
Cell[20321, 520, 1014, 23, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21384, 549, 33, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[21442, 553, 964, 17, 150, "Input"],
Cell[22409, 572, 1011, 23, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23469, 601, 35, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[23529, 605, 964, 17, 150, "Input"],
Cell[24496, 624, 1015, 23, 59, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25560, 653, 33, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[25618, 657, 964, 17, 150, "Input"],
Cell[26585, 676, 1012, 23, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27646, 705, 34, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[27705, 709, 964, 17, 150, "Input"],
Cell[28672, 728, 1011, 23, 57, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

